load_expr

Function load_expr 

pub fn load_expr(store: &dyn Store, id: &ObjectId) -> Result<Expr, VcsError>
Load an expression from the store by its content-addressed ID.

Errors

Returns VcsError::ObjectNotFound if no object exists with the given ID, or VcsError::WrongObjectType if the object is not an expression.