store_expr

Function store_expr 

pub fn store_expr(
    store: &mut dyn Store,
    expr: &Expr,
) -> Result<ObjectId, VcsError>
Serialize an expression and store it as a content-addressed object.

Returns the ObjectId (blake3 hash) of the stored expression. If an identical expression already exists in the store, this is a no-op that returns the existing ID.

Errors

Returns an error if serialization or storage fails.